' Extremely Simple Capture API

Type SimpleCapParams
  ' Target buffer. 
  ' Must be at least mWidth * mHeight * sizeof(int) of size! 
  As long Ptr mTargetBuf
  As long  mWidth
  As long  mHeight
End Type


' Sets up the ESCAPI DLL and the function pointers below. Call this first!
' Returns number of capture devices found (same as countCaptureDevices, below)
Declare Function setupESCAPI() As long

' return the number of capture devices found
Type countCaptureDevicesProc As Function Cdecl As long
Dim Shared As countCaptureDevicesProc countCaptureDevices

' initCapture tries to open the video capture device. 
' Returns 0 on failure, 1 on success. 
' Note: Capture parameter values must not change while capture device
'       is in use (i.e. between initCapture and deinitCapture).
'       Do *not* free the target buffer, or change its pointer!
Type initCaptureProc As Function Cdecl (deviceno As long,p As  SimpleCapParams Ptr) As long
Dim Shared As initCaptureProc initCapture

' deinitCapture closes the video capture device.
Type deinitCaptureProc As Sub Cdecl(deviceno As long)
Dim Shared As deinitCaptureProc deinitCapture

' doCapture requests video frame to be captured.
Type doCaptureProc As Sub Cdecl(deviceno As long)
Dim Shared As doCaptureProc doCapture

' isCaptureDone returns 1 when the requested frame has been captured.
Type isCaptureDoneProc As Function Cdecl(deviceno As long) As long
Dim Shared As isCaptureDoneProc isCaptureDone

' Get the user-friendly name of a capture device.
Type getCaptureDeviceNameProc As Sub Cdecl(deviceno As long,namebuffer As Zstring Ptr,bufferlength As long)
Dim Shared As getCaptureDeviceNameProc getCaptureDeviceName

' Returns the ESCAPI DLL version. 0x200 for 2.0
Type ESCAPIDLLVersionProc As Function() As long
Dim Shared As ESCAPIDLLVersionProc ESCAPIDLLVersion

' Internal: initialize COM
Type initCOMProc As Sub Cdecl
Dim Shared As initCOMProc initCOM

Function setupESCAPI() As long

  ' Load DLL dynamically
  Dim As Any Ptr capdll = DyLibLoad("escapi.dll")
  If (capdll = 0) Then
    Print "can't load 'escapi.dll' !"
    Beep:Sleep:Return 0
  End If
  ' Fetch function DyLibSymbol(escapi_dll,
  countCaptureDevices  = DyLibSymbol(capdll, "countCaptureDevices")
  initCapture          = DyLibSymbol(capdll, "initCapture")
  deinitCapture        = DyLibSymbol(capdll, "deinitCapture")
  doCapture            = DyLibSymbol(capdll, "doCapture")
  isCaptureDone        = DyLibSymbol(capdll, "isCaptureDone")
  initCOM              = DyLibSymbol(capdll, "initCOM")
  getCaptureDeviceName = DyLibSymbol(capdll, "getCaptureDeviceName")
  ESCAPIDLLVersion     = DyLibSymbol(capdll, "ESCAPIDLLVersion")

  If ESCAPIDLLVersion=0 Then
    Print "can't get proc address !"
    Beep:Sleep:Return 0
  End If
  If (ESCAPIDLLVersion() <> &H200) Then
        Print "wrong dll version !"
    Beep:Sleep:Return 0
  End If
  ' Initialize COM.
  initCOM()

  ' and return the number of capture devices found.
  Return countCaptureDevices()
End Function
